==> syncope-2.1.3-source-release.zip: syncope-2.1.3/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/Role.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity;

import org.apache.syncope.core.persistence.api.entity.user.DynRoleMembership;
import java.util.List;
import java.util.Set;

public interface Role extends ProvidedKeyEntity {

    Set<String> getEntitlements();

    boolean add(Realm realm);

    List<? extends Realm> getRealms();

    boolean add(DynRealm dynRealm);

    List<? extends DynRealm> getDynRealms();

    DynRoleMembership getDynMembership();

    void setDynMembership(DynRoleMembership dynMembership);

    String getConsoleLayoutInfo();

    void setConsoleLayoutInfo(String consoleLayoutInfo);

    boolean add(Privilege privilege);

    Set<? extends Privilege> getPrivileges(Application application);

    Set<? extends Privilege> getPrivileges();
}

==> syncope-2.1.11-source-release.zip: syncope-2.1.11/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/Role.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity;

import org.apache.syncope.core.persistence.api.entity.user.DynRoleMembership;
import java.util.List;
import java.util.Set;

public interface Role extends ProvidedKeyEntity {

    Set<String> getEntitlements();

    boolean add(Realm realm);

    List<? extends Realm> getRealms();

    boolean add(DynRealm dynRealm);

    List<? extends DynRealm> getDynRealms();

    DynRoleMembership getDynMembership();

    void setDynMembership(DynRoleMembership dynMembership);

    String getAnyLayout();

    void setAnyLayout(String anyLayout);

    boolean add(Privilege privilege);

    Set<? extends Privilege> getPrivileges(Application application);

    Set<? extends Privilege> getPrivileges();
}
